import spade_fiware_artifacts
"""Top-level package for spade-fiware-artifacts."""

__author__ = """Manel Soler"""
__email__ = "manelbng@gmail.com"
__version__ = "0.1.2"


from .context_broker_inserter import InserterArtifact
from .context_broker_suscription_manager import SubscriptionManagerArtifact